@@ -10,9 +10,11 @@ ui <- bslib::page_sidebar(
       ),
       bslib::accordion_panel(
         'General appearance',
-        numericInput('start', 'Start time (s)', 0),
-        numericInput('end', 'End time (s; 0 = entire file)', 0),
+        numericInput('start', 'Start time (s)', 0, min = 0),
+        numericInput('end', 'End time (s; 0 = entire file)', 0, min = 0),
         checkboxInput('tfrom0', 'Should time run from 0 on the x-axis?', TRUE),
+        selectInput('tUnit', 'What should be the unit of time on the x-axis?',
+                    choices = c('seconds' = 's', 'milliseconds' = 'ms')),
         selectInput('frames', 'Which frames should be plotted?',
                     choices = c('sound', 'spectrogram', 'TextGrid', 'pitch',
                                 'formant', 'intensity'),
@@ -22,12 +24,18 @@ ui <- bslib::page_sidebar(
                   'Relative proportion of frames (comma-delimited)',
                   '0'),
         textInput('mainTitle', 'Title'),
+        numericInput('mainTitleAlignment', 'Title alignment',
+                     0, min = 0, max = 1),
         checkboxInput('start_end_only',
                       'Should only start and end times be shown on the x-axis?',
                       TRUE),
         checkboxInput('min_max_only',
                       'Should only minima and maxima be shown on the y-axis?',
                       TRUE),
+        numericInput('speckleSize', 'Point size of speckled plot components',
+                     1, min = 0),
+        numericInput('drawSize', 'Line width of drawn plot components',
+                     1, min = 0),
         textInput('time_axisLabel', 'x-axis label', 'Time (s)'),
         numericInput('fontSize', 'Font size', 12),
         selectInput('fontFace', 'Font face',
@@ -56,7 +64,10 @@ ui <- bslib::page_sidebar(
                                                            FALSE)),
                              shinyjs::hidden(textInput('wave_channelNamesStr',
                                                        'Custom channel names (comma-delimited)',
-                                                       NA))
+                                                       NA)),
+                             shinyjs::hidden(numericInput('wave_lineWidth',
+                                                          'Line width',
+                                                          1))
       ),
       bslib::accordion_panel(
         'Spectrogram',
@@ -80,7 +91,7 @@ ui <- bslib::page_sidebar(
                                      1000)),
         shinyjs::hidden(selectInput('spec_windowShape', 'Window shape',
                                     choices = c('Gaussian', 'Hamming', 'Hanning',
-                                                'Bartlett', 'square'),
+                                                'Bartlett', 'square', 'Blackman'),
                                     selected = 'Gaussian')),
         shinyjs::hidden(textInput('spec_colors', 'Colors (comma-delimited)',
                                   'white,black'),
@@ -191,7 +202,10 @@ ui <- bslib::page_sidebar(
                                      'Length of analysis window (s)',
                                      0.025)),
         shinyjs::hidden(numericInput('formant_maxN',
-                                     'Maximum number of formants',
+                                     'Maximum number of formants to estimate',
+                                     5)),
+        shinyjs::hidden(numericInput('formant_number',
+                                     'Number of formants to plot',
                                      5)),
         shinyjs::hidden(textInput('formant_color',
                                   'Colors (comma-separated)',
